package com.fs.qw.service;

import com.fs.qw.domain.QwContactWayUser;

import java.util.List;

/**
 * 联系我限制Service接口
 * 
 * @author fs
 * @date 2024-07-23
 */
public interface IQwContactWayUserService 
{
    /**
     * 查询联系我限制
     * 
     * @param id 联系我限制主键
     * @return 联系我限制
     */
    public QwContactWayUser selectQwContactWayUserById(Long id);

    /**
     * 查询联系我限制列表
     * 
     * @param qwContactWayUser 联系我限制
     * @return 联系我限制集合
     */
    public List<QwContactWayUser> selectQwContactWayUserList(QwContactWayUser qwContactWayUser);

    /**
     * 新增联系我限制
     * 
     * @param qwContactWayUser 联系我限制
     * @return 结果
     */
    public int insertQwContactWayUser(QwContactWayUser qwContactWayUser);

    /**
     * 修改联系我限制
     * 
     * @param qwContactWayUser 联系我限制
     * @return 结果
     */
    public int updateQwContactWayUser(QwContactWayUser qwContactWayUser);

    /**
     * 批量删除联系我限制
     * 
     * @param ids 需要删除的联系我限制主键集合
     * @return 结果
     */
    public int deleteQwContactWayUserByIds(Long[] ids);

    /**
     * 删除联系我限制信息
     * 
     * @param id 联系我限制主键
     * @return 结果
     */
    public int deleteQwContactWayUserById(Long id);
}
